rm(list=ls()) # clear the working directory
library(plyr) # will use this for the arrange function
library(Hmisc) #required for %nin%
library(doBy) #required for summaryBy
library(gmodels) # required for the cross table

# --- STEP: open the data files ---
input <- data.frame()
oldWD <- setwd("../../data/raw_data") #file names are relative in the for loop
files <- dir(pattern = "UTM_ActR_RW2_g_*") #files

for (i in files) {
	tmp <- read.table (i, header = T) #read the file
  
	#extract subject number, condition, and counterbalancing
  labels <-  unlist(strsplit(files[match(i, files)], "_")) 
  subject_label <- unlist(strsplit(labels[5], "\\."))[1]
  tmp$subject <- as.numeric(subject_label)
  group_label <- unlist(strsplit(labels[4], "g"))[2]
  tmp$group <- as.numeric(group_label)
  
  #add the content to the data frame
  input <- rbind (input, tmp)
	rm(tmp)
}

setwd(oldWD) # go back to analysis working directory

# --- STEP: make factors of a couple of variables that may be used later on ---
# collapse blocks 1-4, 5-8
input$part <- ifelse(input$block > 4, 'second', 'first')
table(input$block, input$part)
input$part <- factor(input$part)

# create condition variable
input$condition <- 1 + (input$group-1) %/%2
table(input$condition, input$group)
input$condition <- factor(input$condition, levels = c(1:3), labels = c('control', 'reward', 'punish'))
input$group <- NULL # remove the group variable

# adjust RT (relative to onset of go cue)
input$rt <- ifelse(input$rt > 0, input$rt - 1000, 0)

# reinforcement
input$reinforce <- factor(input$adjust, levels = -1:1, labels = c('punish', 'no', 'reward'))
table(input$reinforce, input$adjust)
input$adjust <- NULL

# adjust coding for signal-respond and signal-inhibit trials
input$correct <- ifelse(input$stop == 0, input$correct, 4)
input$correct <- ifelse(input$correct == 4 & input$resp == 0, 5, input$correct)
input$correct <- factor(input$correct, levels = 0:5, labels = c('missed', 'incorrect', 'anticpt', 'correct', 'sr', 'si'))
table(input$correct, input$stop)
table(input$correct, input$stop, input$resp)

# create stop factor with appropriate labels
input$stop <- factor(input$stop, levels = 0:2, labels = c('no', 'left', 'right'))
head(input, 10)

# --- STEP:  basic performance ---
# check overall no-signal performance of all subjects
NC <- subset(input, stop == 'no') 
NC.table <- as.data.frame.matrix(prop.table(table(NC$subject, NC$correct), 1)) # percent correct
subset(NC.table, correct < .70) # only poor performers

# check overall signal performance of all subjects
CS <- subset(input, stop != 'no')
CS.table <- as.data.frame.matrix(prop.table(table(CS$subject, CS$correct), 1)) # percent correct
subset(CS.table, si > .70 | si < .30) # only poor performers

# exclude subjects if needed 
# cut-off: overall 70% responses correct
# 23: 62% correct
# 28: 68% correct
# 39: 68% correct
# 40: 56% correct
# 46: 64% correct
# 47: did not finish the experiment
# 50: 50% correct (stopped responding)
# 52: 26% correct signal trials
# 59: 56% correct 
# 66: 53% correct
# 68: 45% correct
# 87: 64% correct
# 89: 64% correct
# 91: 16% correct signal trials
# 106: 69% correct
# 123: 65% correct
input.all <- input # keep a version of the data when everybody is included

subject_excl <- c(23,28,39,40,46,47,50, 52, 59, 66, 68,87, 89, 91, 106, 123) 
input <- subset (input, subject %nin% subject_excl)
input$subject <- factor(input$subject)

# test if the number of subjects differs reliably
input.all$excl <- ifelse(input.all$subject %in% subject_excl, 'excl', 'incl')
input.all$first <- c(1, ifelse(input.all$subject[1:(nrow(input.all)-1)] == input.all$subject[2:(nrow(input.all))], 0, 1))
check <- subset(input.all, first == 1)
length(unique(check$subject))
CrossTable(check$condition, check$excl, chisq=T, fisher=T, format="SPSS")

# --- STEP:  do some basic design checks ---
table(input$subject, input$stop)
table(input$subject, input$digit)
table(input$digit, input$stop)

table(input$condition, input$reinforce)
table(input$condition, input$reinforce, input$stop)
table(input$condition, input$reinforce, input$correct)

# --- STEP:  write everything to a file ---
save(input, file = "../../data/processed_data/UTM_ActR_RW2.Rdata")